@@ -3,6 +3,5 @@
 #' @returns A single integer.
 #' @noRd
 abi <- function() {
-  # ABI version 14 (compatible with treesitter 0.3.0)
-  14L
+  .Call(treesitter_language_abi, PACKAGE = "treesitter.c")
 }
