@@ -9,8 +9,8 @@
 #' @examples
 #' language()
 language <- function() {
-  pointer <- .Call(ffi_language)
-  
+  pointer <- .Call(treesitter_language)
+
   new_language(
     pointer = pointer,
     abi = abi(),
